@@ -1,6 +1,6 @@
 
 #' @export
-mark_ngrams <- function(x, ngram) {
+mark_ngrams <- function(x, ngram, mapping = NULL) {
 
   if (!is.character(x) || length(x) == 0L) {
     stop("x must be a non-empty character vector.")
@@ -12,7 +12,7 @@ mark_ngrams <- function(x, ngram) {
   # --- Convert to cuneiform if needed ---
   has_cuneiform <- any(grepl("[\U00012000-\U0001254F]", x, perl = TRUE))
   if (!has_cuneiform) {
-    x <- as.cuneiform(x)
+    x <- as.cuneiform(x, mapping = mapping)
   }
 
   # --- Remove spaces and brackets ---
