@@ -18,7 +18,7 @@
   if(msg==""){
     msg <- switch(sample.int(2L, 1L),
         "Watch for dictionary updates:\n    https://founder-hypothesis.com/en/sumerian-mythology/downloads/",
-        "Type ?sumer to get started.")
+        "Type 'browseVignettes(\"sumer\")' to get started.")
   }
 
   packageStartupMessage(msg)
